# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms
from django.db.models import Q
from .models import Course, Section, CourseSectionMid, Video, UserImage, UserCourse, UserAssignment, \
    UserAssignmentImage, SectionVideo, Preference, SectionAttach, UserSectionNote
from django.forms.models import inlineformset_factory


# ===== course contract======
class CourseForm(forms.ModelForm):
    status = forms.ChoiceField(choices=((0, '显示'), (1, '不显示')), label='显示状态')

    class Meta:
        model = Course
        fields = ['name', "subtitle", "level", "status", "image"]


# ===== section contract======
class SectionForm(forms.ModelForm):
    type = forms.ChoiceField(choices=((0, '普通课件'), (1, 'TIPS')), label='课件类型')

    class Meta:
        model = Section
        fields = ['name', 'type', "info", 'video_length_req',
                  'has_imagework', 'image_count_req','auto_pass']

class SectionAttachForm(forms.ModelForm):
    class Meta:
        model = SectionAttach
        fields = ['file']

section_attach_form = inlineformset_factory(Section, SectionAttach, form=SectionAttachForm, extra=1)


# 用户笔记
class UserSectionNoteForm(forms.ModelForm):
    class Meta:
        model = UserSectionNote
        fields = ['note', 'is_open']


class CourseSectionForm(forms.ModelForm):
    class Meta:
        model = CourseSectionMid
        fields = ['section', 'order_by']

    def __init__(self, course=None, *args, **kwargs):
        super(CourseSectionForm, self).__init__(*args, **kwargs)
        if course:
            self.fields['section'].queryset = Section.objects.filter(~Q(coursesectionmid__course=course))


class CourseSectionOrderForm(forms.ModelForm):
    class Meta:
        model = CourseSectionMid
        fields = ['order_by']



class CourseSectionMinForm(forms.ModelForm):
    class Meta:
        model = CourseSectionMid
        fields = ['section', 'order_by', 'mins']


class VideoForm(forms.ModelForm):
    class Meta:
        model = Video
        fields = ['title', 'info']


class UploadImageForm(forms.ModelForm):
    class Meta:
        model = UserImage
        fields = ['image']

class UserCourseForm(forms.ModelForm):
    class Meta:
        model = UserCourse
        fields = ('course',)

    def __init__(self, user, *args, **kwargs):
        super(UserCourseForm, self).__init__(*args, **kwargs)

        self.fields['course'].queryset = Course.objects.exclude(usercourse__user=user)


class UserAssignmentForm(forms.ModelForm):
    class Meta:
        model = UserAssignment
        fields = ['content', ]


class UserAssignmentImageForm(forms.ModelForm):
    class Meta:
        model = UserAssignmentImage
        fields = ['image', ]


class SectionVideoForm(forms.ModelForm):
    class Meta:
        model = SectionVideo
        fields = ['video', 'order']

    def __init__(self, section=None, *args, **kwargs):
        super(SectionVideoForm, self).__init__(*args, **kwargs)

        if section:
            self.fields['video'].queryset = Video.objects.exclude(sectionvideo__section=section)


class SectionVideoOrderForm(forms.ModelForm):
    class Meta:
        model = SectionVideo
        fields = ['order']


class PreferenceForm(forms.ModelForm):
    how_to_pass = forms.ChoiceField(choices=((0,'自动'), (1,'手动')), label='课程通过方式')

    class Meta:
        model = Preference
        fields = ['how_to_pass',]


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-26 05:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0018_auto_20180324_1703'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userassignmentimage',
            name='image',
            field=models.ImageField(upload_to='assignments/%Y/%m/%d', verbose_name='\u56fe\u7247\u4f5c\u4e1a'),
        ),
        migrations.AlterField(
            model_name='userassignmentimage',
            name='user_assignment',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserAssignment'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-08 10:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0005_auto_20180108_1640'),
    ]

    operations = [
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('video_id', models.CharField(max_length=180, null=True)),
                ('status', models.CharField(max_length=180, null=True)),
                ('duration', models.CharField(max_length=180, null=True)),
                ('image', models.CharField(max_length=180, null=True)),
                ('title', models.CharField(max_length=180, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_course_video',
            },
        ),
        migrations.AlterModelOptions(
            name='coursesectionmid',
            options={'ordering': ['order_by']},
        ),
        migrations.AddField(
            model_name='section',
            name='videos',
            field=models.ManyToManyField(to='bee_django_course.Video'),
        ),
    ]



# -*- coding: utf-8 -*-
__author__ = 'bee'

import urllib, urllib2, pytz, json
from django.http import HttpResponse
from datetime import datetime
from django.conf import settings
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger

LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')


# =====http====
def http_get(url):
    f = urllib.urlopen(url)
    s = f.read()
    return s


def http_post(url, parameters=None):
    parameters = urllib.urlencode(parameters)
    request = urllib2.Request(url, parameters)
    request.add_header('Content-Type', 'application/x-www-form-urlencoded')
    res_data = urllib2.urlopen(request, timeout=10)
    res = res_data.read()
    return res


# ====dt====
# 获取本地当前时间
def get_now(tz=LOCAL_TIMEZONE):
    return datetime.now(tz)


class JSONResponse(HttpResponse):
    def __init__(self, obj):
        if isinstance(obj, dict):
            _json_str = json.dumps(obj)
        else:
            _json_str = obj
        super(JSONResponse, self).__init__(_json_str, content_type="application/json;charset=utf-8")


def page_it(request, query_set, url_param_name='page', items_per_page=25):
    paginator = Paginator(query_set, items_per_page)

    page = request.GET.get(url_param_name)
    try:
        rs = paginator.page(page)
    except PageNotAnInteger:
        rs = paginator.page(1)
    except EmptyPage:
        rs = paginator.page(paginator.num_pages)

    return rs


# 获取用户姓名
def get_user_name(user):
    try:
        user_name = getattr(user, settings.USER_NAME_FIELD)
    except:
        user_name = user.username
    return user_name





# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-25 10:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0041_userlive_coin_multiple'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='auto_pass',
            field=models.BooleanField(default=False),
        ),
    ]



# -*- coding:utf-8 -*-
from django.dispatch import Signal

# 作业被评分前发出的信号
assignment_will_be_scored = Signal(providing_args=["user_course_section", "request"])

# 作业评分后发出的信号
assignment_was_scored = Signal(providing_args=["user_course_section", "request"])

# 直播回调后发出的信号
live_callback_finished = Signal(providing_args=["user_live", "coin_multiple"])

# 笔记创建的信号
section_note_created = Signal(providing_args=["user_section_note_id"])



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-25 11:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0042_section_auto_pass'),
    ]

    operations = [
        migrations.AlterField(
            model_name='section',
            name='auto_pass',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u81ea\u52a8\u901a\u8fc7'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-30 07:13
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0022_sectionvideo'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='course',
            options={'ordering': ['-id'], 'permissions': (('can_choose_course', 'can choose course'),)},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-26 05:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0043_auto_20180625_1928'),
    ]

    operations = [
        migrations.AddField(
            model_name='sectionvideo',
            name='order',
            field=models.IntegerField(default=0, verbose_name='\u5728\u8bfe\u4ef6\u91cc\u7684\u6392\u5e8f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-20 03:19
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0011_auto_20180318_1618'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='section',
            name='order_by',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-16 09:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0030_preference'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u8bf4\u660e'),
        ),
        migrations.AlterField(
            model_name='video',
            name='title',
            field=models.CharField(max_length=180, null=True, verbose_name='\u6807\u9898'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-

from django.conf import settings


def get_user_name(request):
    if not request.user.is_authenticated():
        name = '匿名用户'
    else:
        if settings.COURSE_USER_NAME:
            name = getattr(request.user, settings.COURSE_USER_NAME)
            if not name:
                name = request.user.username
        else:
            name = request.user.username

    context = {
        'user_name': name,
    }

    return context
